OriginEnrichmentConfiguration

Struct OriginEnrichmentConfiguration 

pub struct OriginEnrichmentConfiguration {
    pub enabled: bool,
    pub entity_id_precedence: bool,
    pub tag_cardinality: OriginTagCardinality,
    pub origin_detection_unified: bool,
    pub origin_detection_optout: bool,
    pub origin_detection_client: bool,
}
Origin enrichment configuration.

Origin enrichment controls the when and how of enriching metrics ingested via DogStatsD based on various sources of “origin” information, such as specific metric tags or UDS socket credentials. Enrichment involves adding additional metric tags that describe the origin of the metric, such as the Kubernetes pod or container.

Fields

enabled: bool

Whether or not to enable origin detection.

If disabled, no origin tags will be added to events even if the origin information is detected.

entity_id_precedence: bool

Whether or not a client-provided entity ID should take precedence over automatically detected origin metadata.

When a client-provided entity ID is specified, and an origin process ID has automatically been detected, setting this to true will cause the origin process ID to be ignored. This only applies when origin_detection_unified is false.

tag_cardinality: OriginTagCardinality

The cardinality of tags to enrich metrics with, when the payload doesn’t specify one itself.

origin_detection_unified: bool

Whether or not to use the unified origin detection behavior.

When set to true, all detected entity IDs – UDS Origin Detection, dd.internal.entity_id, container ID from DogStatsD payload – will be used for querying tags to enrich with. When set to false, the original precedence behavior will be used, which enriches with the entity ID detected via Origin Detection first, and then potentially again with either the client-provided entity ID (dd.internal.entity_id) or the container ID from the DogStatsD payload, with the client-provided entity ID taking precedence. An entity ID detected via Origin Detection is only used when no client-provided entity ID was present, or when entity_id_precedence is false.

origin_detection_optout: bool

Whether or not to opt out of origin detection for DogStatsD metrics.

When set to true, and the metric explicitly denotes a cardinality of "none", origin enrichment will be skipped. This is only applicable to DogStatsD metrics when unified origin detection behavior isn’t enabled.

origin_detection_client: bool

Whether or not to parse client-provided origin fields from DogStatsD payloads.

When enabled, the c: (Local Data), e: (External Data), and card: (Cardinality) protocol fields are parsed and used for origin enrichment.